==> netbeans_6.5.orig.tar.gz: netbeans-6.5/options.api/src/org/netbeans/modules/options/AdvancedOptionImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.modules.options;

import org.netbeans.spi.options.*;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import java.util.StringTokenizer;

/**
 * Advanced Option implementation class. Used by factory method from
 * <code>AdvancedOption</code> as instance created from layer.xml values
 *
 * @author Max Sauer
 */
public class AdvancedOptionImpl extends AdvancedOption {
    
    private String displayName;
    private String tooltip;
    private String keywords;
    private OptionsPanelController controller;
    private String keywordsCategory;

    public AdvancedOptionImpl(OptionsPanelController controller, String displayName, String tooltip, String keywords, String keywordsCategory) {
        this.controller = controller;
        this.displayName = displayName;
        this.tooltip = tooltip;
        this.keywords = keywords;
        this.keywordsCategory = keywordsCategory;
    }

    @Override
    public String getDisplayName () {
        return displayName;
    }

    @Override
    public String getTooltip () {
        return tooltip;
    }

    /**
     * Provides list of options for this category
     * @return map of path and keywords for each optioncategory sub-panel
     */
    public Map<String, Set<String>> getKeywordsByCategory() {
        HashMap<String, Set<String>> result = new HashMap<String, Set<String>>();
        if(keywordsCategory != null && keywords != null)
            result.put(keywordsCategory, new HashSet(Collections.list(new StringTokenizer(keywords, ",")))); //NOI18N
        return result;
    }

    @Override
    public OptionsPanelController create() {
        return controller;
    }

}

==> netbeans_6.8.orig.tar.gz: netbeans-6.8/options.api/src/org/netbeans/modules/options/AdvancedOptionImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.modules.options;

import java.util.Arrays;
import org.netbeans.spi.options.*;
import java.util.Collections;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.Callable;
import org.openide.util.Exceptions;

/**
 * Advanced Option implementation class. Used by factory method from
 * <code>AdvancedOption</code> as instance created from layer.xml values
 *
 * @author Max Sauer
 */
public class AdvancedOptionImpl extends AdvancedOption {
    
    private String displayName;
    private String tooltip;
    private String keywords;
    private Callable<OptionsPanelController> controller;
    private String keywordsCategory;

    @SuppressWarnings("deprecation")
    public AdvancedOptionImpl(Callable<OptionsPanelController> controller, String displayName, String tooltip, String keywords, String keywordsCategory) {
        this.controller = controller;
        this.displayName = displayName;
        this.tooltip = tooltip;
        this.keywords = keywords;
        this.keywordsCategory = keywordsCategory;
    }

    @Override
    public String getDisplayName () {
        return displayName;
    }

    @Override
    public String getTooltip () {
        return tooltip;
    }

    /**
     * Provides list of options for this category
     * @return map of path and keywords for each optioncategory sub-panel
     */
    public Map<String, Set<String>> getKeywordsByCategory() {
        if (keywordsCategory != null && keywords != null) {
            return Collections.<String,Set<String>>singletonMap(keywordsCategory, new HashSet<String>(Arrays.asList(keywords.split(",")))); // NOI18N
        } else {
            return Collections.emptyMap();
        }
    }

    @Override
    public OptionsPanelController create() {
        try {
            return controller.call();
        } catch (Exception x) {
            Exceptions.printStackTrace(x);
            return new TabbedController("<error>"); // NOI18N
        }
    }

}
